unit MainFrm;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.OleServer, Outlook_TLB, ComObj,
  Vcl.StdCtrls, Vcl.ComCtrls, Vcl.ToolWin,
  System.Actions, Vcl.ActnList, System.ImageList, Vcl.ImgList,
  System.NetEncoding,
  RVStyle, RVScroll, RichView, RVEdit, RVUni, RVTypes, RVGrHandler,
  RichViewActions;

type
  TfrmMain = class(TForm)
    RichViewEdit1: TRichViewEdit;
    RVStyle1: TRVStyle;
    btnSend: TButton;
    btnSave: TButton;
    btnPrint: TButton;
    cmbAccounts: TComboBox;
    Label1: TLabel;
    txtTo: TEdit;
    Label2: TLabel;
    ActionList1: TActionList;
    ImageList1: TImageList;
    rvActionFontBold1: TrvActionFontBold;
    rvActionFontItalic1: TrvActionFontItalic;
    rvActionFontUnderline1: TrvActionFontUnderline;
    rvActionInsertPicture1: TrvActionInsertPicture;
    ToolBar1: TToolBar;
    ToolButton1: TToolButton;
    ToolButton2: TToolButton;
    ToolButton3: TToolButton;
    ToolButton4: TToolButton;
    ToolButton5: TToolButton;
    txtSubject: TEdit;
    Label3: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure btnSendClick(Sender: TObject);
    procedure btnSaveClick(Sender: TObject);
    procedure btnPrintClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
   App : OutlookApplication;
   function CreateMail: _MailItem;
   function GetSelectedAccount: _Account;
   function GetEmailBody: UnicodeString;
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.dfm}


procedure TfrmMain.FormCreate(Sender: TObject);
var
 Account: _Account;
 i: Integer;
begin
  try
    // Creating Outlook Application object
    App := CreateOleObject('Outlook.Application') as _Application;
    // List of accounts --> cmbAccounts
    for i := 1 to App.Session.Accounts.Count do
    begin
      Account := App.Session.Accounts.Item(i);
      // probably we should check Account.AccountType here
      cmbAccounts.Items.Add(Account.DisplayName);
    end;
    if cmbAccounts.Items.Count = 0 then
    begin
      Application.MessageBox('Outlook accounts are not found', nil, MB_OK or MB_ICONSTOP);
      Application.Terminate;
    end;
    cmbAccounts.ItemIndex := 0;
  except
    Application.MessageBox('Cannot initialize Outlook', nil, MB_OK or MB_ICONSTOP);
    Application.Terminate;
  end;
end;

// Returns e-mail body as HTML
function TfrmMain.GetEmailBody: UnicodeString;
var
  Stream: TMemoryStream;
begin
  // These settings could me made at design time. They are important.
  RichViewEdit1.HTMLSaveProperties.ImageOptions :=
    RichViewEdit1.HTMLSaveProperties.ImageOptions + [rvhtmlsioInlineImages,
      rvhtmlsioImageSizeAttributes];
  RichViewEdit1.HTMLSaveProperties.CSSSavingType := rvcssstInline;
  // Saving to HTML
  Stream := TMemoryStream.Create;
  try
    RichViewEdit1.SaveHTMLToStream(Stream, '', rvhtmlspMiddle);
    Stream.Position := 0;
    Result := UTF8Decode(RVU_AnsiStreamToAnsiString(Stream));
  finally
    Stream.Free;
  end;
end;

// Returns POP3 account selected in cmbAccounts
function TfrmMain.GetSelectedAccount: _Account;
var
  i: Integer;
begin
  for i := 1 to App.Session.Accounts.Count do
    begin
      Result := App.Session.Accounts.Item(i);
      if Result.DisplayName = cmbAccounts.Items[cmbAccounts.ItemIndex] then
       exit;
    end;
  Result := nil;
end;

// Creates MailItem and fills its properties
function TfrmMain.CreateMail: _MailItem;
begin
  Result := App.CreateItem(olMailItem) as _MailItem;
  Result.Subject := txtSubject.Text;
  // Result.To_ := txtTo.Text;
  Result.Recipients.Add(txtTo.Text);
  Result.Recipients.ResolveAll;
  Result.SendUsingAccount := GetSelectedAccount;
  Result.BodyFormat := olFormatHTML;
  Result.HTMLBody := GetEmailBody;
end;

// Printing e-mail
procedure TfrmMain.btnPrintClick(Sender: TObject);
begin
  CreateMail.PrintOut;
end;

// Saving e-mail
procedure TfrmMain.btnSaveClick(Sender: TObject);
begin
  CreateMail.Save;
  Application.MessageBox('The message was saved in Drafts', 'Info', MB_OK or MB_ICONINFORMATION);
end;

// Sending e-mail
procedure TfrmMain.btnSendClick(Sender: TObject);
begin
  CreateMail.Send;
  Application.MessageBox('The message was sent/placed to Outbox', 'Info', MB_OK or MB_ICONINFORMATION);
end;


end.
